<div class="mod-pedal mod-pedal-ratatouille{{{cns}}} ">
    <div mod-role="drag-handle" class="mod-drag-handle"></div>
        {{#controls.14}}
        <div class="mod-bufferswitch" title="{{name}}">
            <div class="mod-bufferswitch-image" mod-role="input-control-port" mod-port-symbol="{{symbol}}" mod-widget="switch"></div>
            <span class="mod-switch-title">{{name}}</span>
        </div>
        {{/controls.14}}
        {{#controls.15}}
        <div class="mod-phaseswitch" title="{{name}}">
            <div class="mod-phaseswitch-image" mod-role="input-control-port" mod-port-symbol="{{symbol}}" mod-widget="switch"></div>
            <span class="mod-switch-title">{{name}}</span>
        </div>
        {{/controls.15}}
        <div class="buffertext" rata-role="latency"></div>
    <div class="mod-powerswitch" mod-role="bypass">
        <div class="mod-powerswitch-image" mod-role="bypass-light"></div>
    </div>

    <div class="mod-control-group mod-{{knob}} top clearfix">
        {{#controls.0}}
        <div class="mod-knob" title="{{name}}">
            <div class="mod-knob-image" mod-role="input-control-port" mod-port-symbol="{{symbol}}"></div>
            <span class="mod-knob-title">{{name}}</span>
        </div>
        {{/controls.0}}
        {{#controls.1}}
        <div class="mod-knob" title="{{name}}">
            <div class="mod-knob-image" mod-role="input-control-port" mod-port-symbol="{{symbol}}"></div>
            <span class="mod-knob-title">{{name}}</span>
        </div>
        {{/controls.1}}
        {{#controls.2}}
        <div class="mod-knob" title="{{name}}">
            <div class="mod-knob-image" mod-role="input-control-port" mod-port-symbol="{{symbol}}"></div>
            <span class="mod-knob-title">{{name}}</span>
        </div>
        {{/controls.2}}
        {{#controls.3}}
        <div class="mod-knob" title="{{name}}">
            <div class="mod-knob-image" mod-role="input-control-port" mod-port-symbol="{{symbol}}"></div>
            <span class="mod-knob-title">{{name}}</span>
        </div>
        {{/controls.3}}
        {{#controls.4}}
        <div class="mod-knob" title="{{name}}">
            <div class="mod-knob-image" mod-role="input-control-port" mod-port-symbol="{{symbol}}"></div>
            <span class="mod-knob-title">{{name}}</span>
        </div>
        {{/controls.4}}
        {{#controls.5}}
        <div class="mod-knob" title="{{name}}">
            <div class="mod-knob-image" mod-role="input-control-port" mod-port-symbol="{{symbol}}"></div>
            <span class="mod-knob-title">{{name}}</span>
        </div>
        {{/controls.5}}
    </div>
    <div class="mod-control-group mod-enumerated-group bottom clearfix">
        {{#controls.8}}
        <div class="mod-switch" title="{{name}}">
            <div class="mod-switch-image" mod-role="input-control-port" mod-port-symbol="{{symbol}}" mod-widget="switch"></div>
        </div>
        {{/controls.8}}
        {{#controls.10}}
        <div class="mod-switch2" title="{{name}}">
            <div class="mod-button-image" mod-role="input-control-port" mod-port-symbol="{{symbol}}" mod-widget="switch"></div>
        </div>
        {{/controls.10}}
        {{#effect.parameters.0}}
        {{#path}}
        <div class="mod-enumerated" mod-role="input-parameter" mod-parameter-uri="{{uri}}" mod-widget="custom-select-path">
            <div mod-role="input-parameter-value" rata-role="SlotA" mod-parameter-uri="{{uri}}" class="mod-enumerated-selected">
                -- choose a NAM/AIDA-X model --
            </div>
            <div class="mod-enumerated-list">
                {{#files}}
                <div mod-role="enumeration-option" mod-parameter-value="{{fullname}}">{{basename}}</div>
                {{/files}}
            </div>
        </div>
        {{/path}}
        {{/effect.parameters.0}}
        {{#controls.9}}
        <div class="mod-switch" title="{{name}}">
            <div class="mod-switch-image" mod-role="input-control-port" mod-port-symbol="{{symbol}}" mod-widget="switch"></div>
        </div>
        {{/controls.9}}
        {{#controls.11}}
        <div class="mod-switch2" title="{{name}}">
            <div class="mod-button-image" mod-role="input-control-port" mod-port-symbol="{{symbol}}" mod-widget="switch"></div>
        </div>
        {{/controls.11}}
        {{#effect.parameters.1}}
        {{#path}}
        <div class="mod-enumerated" mod-role="input-parameter" mod-parameter-uri="{{uri}}" mod-widget="custom-select-path">
            <div mod-role="input-parameter-value" rata-role="SlotB" mod-parameter-uri="{{uri}}" class="mod-enumerated-selected">
                -- choose a NAM/AIDA-X model --
            </div>
            <div class="mod-enumerated-list">
                {{#files}}
                <div mod-role="enumeration-option" mod-parameter-value="{{fullname}}">{{basename}}</div>
                {{/files}}
            </div>
        </div>
        {{/path}}
        {{/effect.parameters.1}}
        {{#controls.6}}
        <div class="mod-switch" title="{{name}}">
            <div class="mod-switch-image" mod-role="input-control-port" mod-port-symbol="{{symbol}}" mod-widget="switch"></div>
        </div>
        {{/controls.6}}
        {{#controls.12}}
        <div class="mod-switch2" title="{{name}}">
            <div class="mod-button-image" mod-role="input-control-port" mod-port-symbol="{{symbol}}" mod-widget="switch"></div>
        </div>
        {{/controls.12}}
        {{#effect.parameters.2}}
        {{#path}}
        <div class="mod-enumerated" mod-role="input-parameter" mod-parameter-uri="{{uri}}" mod-widget="custom-select-path">
            <div mod-role="input-parameter-value" rata-role="IrA" mod-parameter-uri="{{uri}}" class="mod-enumerated-selected">
                -- choose an IR file --
            </div>
            <div class="mod-enumerated-list">
                {{#files}}
                <div mod-role="enumeration-option" mod-parameter-value="{{fullname}}">{{basename}}</div>
                {{/files}}
            </div>
        </div>
        {{/path}}
        {{/effect.parameters.2}}
        {{#controls.7}}
        <div class="mod-switch" title="{{name}}">
            <div class="mod-switch-image" mod-role="input-control-port" mod-port-symbol="{{symbol}}" mod-widget="switch"></div>
        </div>
        {{/controls.7}}
        {{#controls.13}}
        <div class="mod-switch2" title="{{name}}">
            <div class="mod-button-image" mod-role="input-control-port" mod-port-symbol="{{symbol}}" mod-widget="switch"></div>
        </div>
        {{/controls.13}}
        {{#effect.parameters.3}}
        {{#path}}
        <div class="mod-enumerated" mod-role="input-parameter" mod-parameter-uri="{{uri}}" mod-widget="custom-select-path">
            <div mod-role="input-parameter-value" rata-role="IrB" mod-parameter-uri="{{uri}}" class="mod-enumerated-selected">
                -- choose an IR file --
            </div>
            <div class="mod-enumerated-list">
                {{#files}}
                <div mod-role="enumeration-option" mod-parameter-value="{{fullname}}">{{basename}}</div>
                {{/files}}
            </div>
        </div>
        {{/path}}
        {{/effect.parameters.3}}
    </div>
    <div class="mod-pedal-input">
        {{#effect.ports.audio.input}}
        <div class="mod-input mod-input-disconnected" title="{{name}}" mod-role="input-audio-port" mod-port-symbol="{{symbol}}">
            <div class="mod-pedal-input-image"></div>
        </div>
        {{/effect.ports.audio.input}}
    </div>
    <div class="mod-pedal-output">
        {{#effect.ports.audio.output}}
        <div class="mod-output mod-output-disconnected" title="{{name}}" mod-role="output-audio-port" mod-port-symbol="{{symbol}}">
            <div class="mod-pedal-output-image"></div>
        </div>
        {{/effect.ports.audio.output}}
    </div>
</div>
