/* STYLES FOR THE RATATOUILLE PEDAL */

@import url(/fonts/nexa/stylesheet.css);
@import url(/fonts/questrial/stylesheet.css);


/* = CONTAINER
================================================ */
.mod-pedal-ratatouille{{{cns}}} {
    background-image:url(/resources/pedals/Ratatouille.png{{{ns}}});
    background-position:center center;
    background-repeat:no-repeat;
    background-size:595px 403px;
    height:403px;
    position:absolute;
    width:595px;
    border-radius: 21px;
}

/* PORTS
================================================ */

.mod-pedal-ratatouille{{{cns}}} .mod-pedal-input,
.mod-pedal-ratatouille{{{cns}}} .mod-pedal-output {
    top: 96px;
}

/* POWER SWITCH ON/OFF GENERAL 
================================================*/
.mod-pedal-ratatouille{{{cns}}} .mod-powerswitch {
    margin-left: 495px ;
    margin-top: 12px ;
    cursor: pointer;
    float: left;
    position: absolute;
    height: 30px;
    width: 60px;
    z-index:40;
}

.mod-pedal-ratatouille{{{cns}}} .mod-powerswitch-image {
    background-image: url(/resources/switches/powerswitch.png{{{ns}}});
    background-position: 0px 0px;
    background-repeat: no-repeat;
    background-size: auto 30px;
    height: 30px;
    width: 60px;
}

.mod-pedal-ratatouille{{{cns}}} .mod-powerswitch-image.on {
    background-position: -60px 0px;
}

.mod-pedal-ratatouille{{{cns}}} .mod-powerswitch-image.off {
    background-position: 0px 0px;
}

/* BUFFER SWITCH ON/OFF 
================================================*/
.mod-pedal-ratatouille{{{cns}}} .mod-bufferswitch {
    margin-left: 45px ;
    margin-top: 12px ;
    cursor: pointer;
    float: left;
    position: absolute;
    height: 32px;
    width: 30px;
    z-index:40;
}

.mod-pedal-ratatouille{{{cns}}} .mod-bufferswitch-image {
    background-image: url(/resources/switches/powerswitch.png{{{ns}}});
    background-position: 0px 0px;
    background-repeat: no-repeat;
    background-size: auto 15px;
    height: 15px;
    width: 30px;
}

.mod-pedal-ratatouille{{{cns}}} .mod-bufferswitch-image.on {
    background-position: -30px 0px;
}

.mod-pedal-ratatouille{{{cns}}} .mod-bufferswitch-image.off {
    background-position: 0px 0px;
}

.mod-pedal-ratatouille{{{cns}}} .mod-bufferswitch .mod-switch-title {
    font-family: "Helvetica Neue",Helvetica,Arial,sans-serif;
    font-size: 10px;
    font-weight: bold;
    left: 0;
    color:#888;
    position: absolute;
    right: 0;
    margin-top: 17px;
    top: 0;
    z-index: 1;
}

/* LATENCY REPORT
================================================*/
.mod-pedal-ratatouille{{{cns}}} .buffertext {
    position: absolute;
    margin-top: 29px;
    width: 60%;
    height: 100%;
    text-align: center;
    font-family: "Helvetica Neue",Helvetica,Arial,Sans-serif;
    font-weight: bold;
    font-size: 10px;
    color: #888;
    z-index: 1;
}

/* PHASE SWITCH ON/OFF 
================================================*/
.mod-pedal-ratatouille{{{cns}}} .mod-phaseswitch {
    margin-left: 95px ;
    margin-top: 12px ;
    cursor: pointer;
    float: left;
    position: absolute;
    height: 32px;
    width: 30px;
    z-index:40;
}

.mod-pedal-ratatouille{{{cns}}} .mod-phaseswitch-image {
    background-image: url(/resources/switches/powerswitch.png{{{ns}}});
    background-position: 0px 0px;
    background-repeat: no-repeat;
    background-size: auto 15px;
    height: 15px;
    width: 30px;
}

.mod-pedal-ratatouille{{{cns}}} .mod-phaseswitch-image.on {
    background-position: -30px 0px;
}

.mod-pedal-ratatouille{{{cns}}} .mod-phaseswitch-image.off {
    background-position: 0px 0px;
}

.mod-pedal-ratatouille{{{cns}}} .mod-phaseswitch .mod-switch-title {
    font-family: "Helvetica Neue",Helvetica,Arial,sans-serif;
    font-size: 10px;
    font-weight: bold;
    left: 0;
    color:#888;
    position: absolute;
    right: 0;
    margin-top: 17px;
    top: 0;
    z-index: 1;
}

/* = SWITCH ON/OFF
================================================  */
.mod-pedal-ratatouille{{{cns}}} .mod-switch {
    margin-left: 10px ;
    margin-top: 3px ;
    cursor: pointer;
    float: left;
    height: 20px;
    position: relative;
    top: 0px;
    width: 20px;
}

.mod-pedal-ratatouille{{{cns}}} .mod-switch-image {
    background-image: url(/resources/switches/normalize.png{{{ns}}});
    background-position: 0px 0px;
    background-repeat: no-repeat;
    background-size: auto 20px;
    height: 20px;
    width: 20px;
}

.mod-pedal-ratatouille{{{cns}}} .mod-switch-image.on {
    background-position: -20px 0px;
}

.mod-pedal-ratatouille{{{cns}}} .mod-switch-image.off {
    background-position: 0px 0px;
}

/* = Button ON/OFF
================================================  */
.mod-pedal-ratatouille{{{cns}}} .mod-switch2 {
    margin-top: 3px ;
    cursor: pointer;
    float: right;
    height: 20px;
    position: relative;
    top: 0px;
    width: 20px;
}

.mod-pedal-ratatouille{{{cns}}} .mod-button-image {
    background-image: url(/resources/switches/eject.png{{{ns}}});
    background-position: 0px 0px;
    background-repeat: no-repeat;
    background-size: auto 20px;
    height: 20px;
    width: 20px;
}

.mod-pedal-ratatouille{{{cns}}} .mod-button-image.on {
    background-position: -20px 0px;
}

.mod-pedal-ratatouille{{{cns}}} .mod-button-image.off {
    background-position: 0px 0px;
}

/* = KNOBS
================================================ */
.mod-pedal-ratatouille{{{cns}}} .mod-control-group {
    margin:10px !important; 
    position:relative;
    text-align:center;
    z-index:30;
}

.mod-pedal-ratatouille{{{cns}}} .top {
    margin-top:73px !important;
    margin-right:0px !important;
    margin-left:0px !important;
}

.mod-pedal-ratatouille{{{cns}}} .bottom {
    margin-top:0px ;
    margin-right:0px ;
    margin-left:0px ;
    width: 590px;
}

.mod-pedal-ratatouille{{{cns}}} .mod-control-group .mod-knob {
    overflow:hidden;
    position:relative;
}

.mod-pedal-ratatouille{{{cns}}} .mod-control-group .mod-knob .mod-knob-image {
    background-repeat:no-repeat;
    background-size:auto 90px;
    height:90px;
    width:90px;
    margin-bottom: 0px;
    margin-top: 10px;
}

.mod-pedal-ratatouille{{{cns}}} .mod-control-group .mod-knob {
    display:inline-block;
    height:140px;
}

.mod-pedal-ratatouille{{{cns}}} .mod-control-group .mod-knob-title {
    font-family: "Helvetica Neue",Helvetica,Arial,sans-serif;
    font-size: 14px;
    font-weight: bold;
    left: 0;
    color:#fff;
    position: absolute;
    right: 0;
    text-transform: uppercase;
    margin-top: 105px;
    top: 0;
    z-index: 1;
}

/* = ENUMERATED LIST
================================================ */
.mod-pedal-ratatouille{{{cns}}} .mod-enumerated-group {
    height:31px;
    margin:20px 30px 0 !important;
    position:relative;
    width:525px;
    z-index:35;
    margin-bottom:10px !important;
}

.mod-pedal-ratatouille{{{cns}}} .mod-enumerated {
    margin-left: 90px;
    margin-bottom: 12px;
/*     display:inline-block; */
    background-position:right center;
    background-repeat:no-repeat;
    font-size:14px;
    font-weight:bold;
    color:#fff;
    left:0;
    line-height:2;
    overflow:hidden;
    position:initial;
    right:0;
    text-align:left;
    z-index: 40;
}

.mod-pedal-ratatouille{{{cns}}} .mod-enumerated .mod-enumerated-selected {
    border-radius:4px 4px 0 0;
    overflow: hidden;
    text-overflow: ellipsis;
    display: -webkit-box;
    -webkit-line-clamp: 1;
           line-clamp: 1;
    -webkit-box-orient: vertical;
}

.mod-pedal-ratatouille{{{cns}}} .mod-enumerated .mod-enumerated-list {
    display:none;
    color:#fff;
    width:100%;
}

.mod-pedal-ratatouille{{{cns}}} .mod-enumerated .mod-enumerated-list {
    background-color:rgba(0,0,0,.9);
    display:none;
    height:230px;
    overflow:auto;
    position:absolute;
    z-index: 50 !important;
}

.mod-pedal-ratatouille{{{cns}}} .mod-enumerated .mod-enumerated-list > div {
    padding:3px 9px;
}

.mod-pedal-ratatouille{{{cns}}} .mod-enumerated .mod-enumerated-list > div:hover {
    background-color:rgba(255,255,255,.2);
    cursor:pointer;
}

/* = KNOBS
================================================ */
.mod-pedal-ratatouille{{{cns}}} .mod-control-group .mod-knob .mod-knob-image
{
    background-image:url(/resources/knobs/knob.png{{{ns}}})
}
